|chartwerk|
===========

| |PyPI version|   |PyPI|   |Requirements Status|

A Django application to manage, create and share Chartwerk charts, built
with `Django REST framework`_.

For the React/Redux-based chart editor, see `chartwerk-editor`_.

Documentation hosted at `django-chartwerk.readthedocs.org`_.

.. _Django REST framework: http://www.django-rest-framework.org/
.. _chartwerk-editor: https://github.com/DallasMorningNews/chartwerk-editor
.. _django-chartwerk.readthedocs.org: https://django-chartwerk.readthedocs.io

.. |chartwerk| image:: docs/images/logo.png
.. |PyPI version| image:: https://badge.fury.io/py/django-chartwerk.svg
   :target: https://pypi.org/project/django-chartwerk/
.. |PyPI| image:: https://img.shields.io/pypi/status/django-chartwerk.svg
   :target: https://pypi.org/project/django-chartwerk/
.. |Requirements Status| image:: https://img.shields.io/requires/github/DallasMorningNews/django-chartwerk.svg?maxAge=2592000
   :target: https://requires.io/github/DallasMorningNews/django-chartwerk/requirements/?branch=master
